==> openedx_django_wiki-2.0.0-py3-none-any.whl: wiki/plugins/images/migrations/0001_initial.py <==
from django.db import models, migrations
import wiki.plugins.images.models


class Migration(migrations.Migration):

    dependencies = [
        ('wiki', '0004_increase_slug_size'),
    ]

    operations = [
        migrations.CreateModel(
            name='Image',
            fields=[
                ('revisionplugin_ptr', models.OneToOneField(parent_link=True, auto_created=True, primary_key=True, serialize=False, to='wiki.RevisionPlugin', on_delete=models.CASCADE)),
            ],
            options={
                'verbose_name': 'image',
                'verbose_name_plural': 'images',
                'db_table': 'wiki_images_image',
            },
            bases=('wiki.revisionplugin',),
        ),
        migrations.CreateModel(
            name='ImageRevision',
            fields=[
                ('revisionpluginrevision_ptr', models.OneToOneField(parent_link=True, auto_created=True, primary_key=True, serialize=False, to='wiki.RevisionPluginRevision', on_delete=models.CASCADE)),
                ('image', models.ImageField(upload_to=wiki.plugins.images.models.upload_path, width_field=b'width', height_field=b'height', max_length=2000, blank=True, null=True)),
                ('width', models.SmallIntegerField(null=True, blank=True)),
                ('height', models.SmallIntegerField(null=True, blank=True)),
            ],
            options={
                'ordering': ('-created',),
                'verbose_name': 'image revision',
                'verbose_name_plural': 'image revisions',
                'db_table': 'wiki_images_imagerevision',
            },
            bases=('wiki.revisionpluginrevision',),
        ),
    ]

==> openedx_django_wiki-3.1.1-py3-none-any.whl: wiki/plugins/images/migrations/0001_initial.py <==
from django.db import models, migrations
import wiki.plugins.images.models


class Migration(migrations.Migration):

    dependencies = [
        ('wiki', '0004_increase_slug_size'),
    ]

    operations = [
        migrations.CreateModel(
            name='Image',
            fields=[
                ('revisionplugin_ptr', models.OneToOneField(parent_link=True, auto_created=True, primary_key=True, serialize=False, to='wiki.RevisionPlugin', on_delete=models.CASCADE)),
            ],
            options={
                'verbose_name': 'image',
                'verbose_name_plural': 'images',
                'db_table': 'wiki_images_image',
            },
            bases=('wiki.revisionplugin',),
        ),
        migrations.CreateModel(
            name='ImageRevision',
            fields=[
                ('revisionpluginrevision_ptr', models.OneToOneField(parent_link=True, auto_created=True, primary_key=True, serialize=False, to='wiki.RevisionPluginRevision', on_delete=models.CASCADE)),
                ('image', models.ImageField(upload_to=wiki.plugins.images.models.upload_path, width_field='width', height_field='height', max_length=2000, blank=True, null=True)),
                ('width', models.SmallIntegerField(null=True, blank=True)),
                ('height', models.SmallIntegerField(null=True, blank=True)),
            ],
            options={
                'ordering': ('-created',),
                'verbose_name': 'image revision',
                'verbose_name_plural': 'image revisions',
                'db_table': 'wiki_images_imagerevision',
            },
            bases=('wiki.revisionpluginrevision',),
        ),
    ]
